class dataclass:
    title = None
    id = None
    identifier_type = None
    type = None
    genres = None
    score = None
    language = None
    episodes = None
    chapters = None
    duration = None
    status = None
    synopsis = None
    url = None

    _identifier_types = ["movie", "tv", "wiki", "anime", "manga"]

    def __init__(self):
        pass

    def __str__(self):
        if self.identifier_type is None or self.identifier_type not in self._identifier_types:
            return "Invalid Identifier Type"

        elif self.identifier_type == "wiki":
            msg = f"\033[4m{self.title}\033[0m:" + "\n\n" + self.synopsis
            return msg

        else:
            msg = []
            m = self.datadict()
            for i in m:
                if m[i] is not None:
                    msg.append(f"{i}: {m[i]}")
            return "\n".join(msg)

    def datadict(self):
        return {
            "Title": self.title,
            "ID": self.id,
            "Type": self.type,
            "Genres": self.genres,
            "Score": self.score,
            "Language": self.language,
            "Episodes": self.episodes,
            "Chapters": self.chapters,
            "Duration": self.duration,
            "Status": self.status,
            "Synopsis": self.synopsis,
            "Url": self.url
        }



import requests
from .helpers.DataClass import dataclass
from .helpers.iso_language_codes import getLanguage


class TMDB:

    def __init__(self, api_key):
        self.base_url = "https://api.themoviedb.org/3"
        self.api_key = api_key

    def _call(self, result):
        if self.api_key is None or self.api_key == '':
            raise TMDbException("No Api Key")

        if "success" in result and result["success"] is False:
            raise TMDbException(result["status_message"])

        if result["results"] == [] or result["results"] is None:
            TMDbException("There are no results that matched your query")

    @staticmethod
    def sendRequest(url):
        return requests.get(url).json()

    def getGenre(self, media_type, genre_ids: list) -> str:
        url = f"https://api.themoviedb.org/3/genre/{media_type}/list?api_key={self.api_key}"
        res = self.sendRequest(url)
        genre_dict = {}

        for i in res["genres"]:
            genre_dict[i["id"]] = i["name"]

        genre_str_list = []
        for j in genre_ids:
            genre_str_list.append(genre_dict.get(j))

        return ", ".join(genre_str_list)

    def url_builder(self, media_type: str, query: str):
        query = query.replace(' ', '%20')
        return self.base_url + f"/search/{media_type}?api_key={self.api_key}&query={query}&page=1"

    def Movie(self, query: str):
        res = self.sendRequest(self.url_builder("movie", query))
        self._call(res)
        data_list = []
        for i in res["results"]:
            movie = dataclass()
            movie.title = i["title"]
            movie.id = i["id"]
            movie.genres = self.getGenre("movie", i["genre_ids"])
            movie.score = i["vote_average"]
            movie.language = getLanguage(i["original_language"])
            movie.synopsis = i["overview"]
            movie.identifier_type = "movie"
            movie.url = "https://www.themoviedb.org/" + movie.identifier_type + "/" + str(movie.id)

            data_list.append(movie)

        return data_list

    def Tv(self, query: str):
        res = self.sendRequest(self.url_builder("movie", query))
        self._call(res)
        data_list = []
        for i in res["results"]:
            tv = dataclass()
            tv.title = i["name"]
            tv.id = i["id"]
            tv.genres = self.getGenre("tv", i["genre_ids"])
            tv.score = i["vote_average"]
            tv.language = i["original_language"]
            tv.synopsis = i["overview"]
            tv.identifier_type = "tv"
            tv.url = "https://www.themoviedb.org/" + tv.identifier_type + "/" + str(tv.id)

            data_list.append(tv)

        return data_list


class TMDbException(Exception):
    pass






import requests
from .helpers.DataClass import dataclass


class MAL:
    order_by = "favorites"
    limit = 10
    sort = "desc"

    def __init__(self):
        self.base_url = "https://api.jikan.moe/v4/"

    @staticmethod
    def sendRequest(url):
        return requests.get(url).json()

    def url_builder(self, media_type: str, query: str):
        query = query.replace(" ", "+")
        return self.base_url + media_type + f"?q={query}&limit={self.limit}&order_by={self.order_by}&sort={self.sort}"

    def _call(self, result):
        if result["data"] == [] or result["data"] is None:
            raise MalExceptions("There are no results that matched your query")
        if self.order_by not in ["mal_id", "title", "type", "rating", "start_date", "end_date", "episodes", "score",
                                 "scored_by", "rank", "popularity", "members", "favorites"]:
            raise MalExceptions("Invalid OrderBy Flag")
        if self.sort not in ["asc", "desc"]:
            MalExceptions("Invalid sort flag")

    @staticmethod
    def getGenre(data) -> list:
        genre_list = []
        for i in data["genres"]:
            genre_list.append(i["name"])
        return ", ".join(genre_list)

    def anime(self, query):
        res = self.sendRequest(self.url_builder("anime", query))
        self._call(res)
        data_list = []
        for i in res["data"]:
            anime = dataclass()
            anime.identifier_type = "anime"
            anime.id = i["mal_id"]
            anime.url = i["url"]
            anime.title = i["title"]
            anime.type = i["type"]
            anime.episodes = i["episodes"]
            anime.status = i["status"]
            anime.duration = i["duration"]
            anime.score = i["score"]
            anime.synopsis = i["synopsis"]
            anime.genres = self.getGenre(i)

            data_list.append(anime)

        return data_list

    def manga(self, query):
        res = self.sendRequest(self.url_builder("manga", query))
        self._call(res)
        data_list = []
        for i in res["data"]:
            manga = dataclass()
            manga.identifier_type = "anime"
            manga.id = i["mal_id"]
            manga.url = i["url"]
            manga.title = i["title"]
            manga.type = i["type"]
            manga.chapters = i["chapters"]
            manga.status = i["status"]
            manga.score = i["score"]
            manga.synopsis = i["synopsis"]
            manga.genres = self.getGenre(i)

            data_list.append(manga)

        return data_list


class MalExceptions(Exception):
    pass




import wikipedia
from .helpers.DataClass import dataclass


class WIKI:

    def __init__(self, query):
        self.query = query

    def _call(self, obj):
        if obj is None or obj == []:
            raise WikiExceptions("There are no results that matched your query")

    def result(self):
        search = wikipedia.search(self.query)
        self._call(search)
        page = wikipedia.page(search[0])
        wiki = dataclass()
        wiki.identifier_type = "wiki"
        wiki.title = page.title
        wiki.synopsis = page.summary
        wiki.url = page.url

        return [wiki]


class WikiExceptions(Exception):
    pass



isoLangs = {
    "ab": {
        "name": "Abkhaz",
        "nativeName": "аҧсуа"
    },
    "aa": {
        "name": "Afar",
        "nativeName": "Afaraf"
    },
    "af": {
        "name": "Afrikaans",
        "nativeName": "Afrikaans"
    },
    "ak": {
        "name": "Akan",
        "nativeName": "Akan"
    },
    "sq": {
        "name": "Albanian",
        "nativeName": "Shqip"
    },
    "am": {
        "name": "Amharic",
        "nativeName": "አማርኛ"
    },
    "ar": {
        "name": "Arabic",
        "nativeName": "العربية"
    },
    "an": {
        "name": "Aragonese",
        "nativeName": "Aragonés"
    },
    "hy": {
        "name": "Armenian",
        "nativeName": "Հայերեն"
    },
    "as": {
        "name": "Assamese",
        "nativeName": "অসমীয়া"
    },
    "av": {
        "name": "Avaric",
        "nativeName": "авар мацӀ, магӀарул мацӀ"
    },
    "ae": {
        "name": "Avestan",
        "nativeName": "avesta"
    },
    "ay": {
        "name": "Aymara",
        "nativeName": "aymar aru"
    },
    "az": {
        "name": "Azerbaijani",
        "nativeName": "azərbaycan dili"
    },
    "bm": {
        "name": "Bambara",
        "nativeName": "bamanankan"
    },
    "ba": {
        "name": "Bashkir",
        "nativeName": "башҡорт теле"
    },
    "eu": {
        "name": "Basque",
        "nativeName": "euskara, euskera"
    },
    "be": {
        "name": "Belarusian",
        "nativeName": "Беларуская"
    },
    "bn": {
        "name": "Bengali",
        "nativeName": "বাংলা"
    },
    "bh": {
        "name": "Bihari",
        "nativeName": "भोजपुरी"
    },
    "bi": {
        "name": "Bislama",
        "nativeName": "Bislama"
    },
    "bs": {
        "name": "Bosnian",
        "nativeName": "bosanski jezik"
    },
    "br": {
        "name": "Breton",
        "nativeName": "brezhoneg"
    },
    "bg": {
        "name": "Bulgarian",
        "nativeName": "български език"
    },
    "my": {
        "name": "Burmese",
        "nativeName": "ဗမာစာ"
    },
    "ca": {
        "name": "Catalan; Valencian",
        "nativeName": "Català"
    },
    "ch": {
        "name": "Chamorro",
        "nativeName": "Chamoru"
    },
    "ce": {
        "name": "Chechen",
        "nativeName": "нохчийн мотт"
    },
    "ny": {
        "name": "Chichewa; Chewa; Nyanja",
        "nativeName": "chiCheŵa, chinyanja"
    },
    "zh": {
        "name": "Chinese",
        "nativeName": "中文 (Zhōngwén), 汉语, 漢語"
    },
    "cv": {
        "name": "Chuvash",
        "nativeName": "чӑваш чӗлхи"
    },
    "kw": {
        "name": "Cornish",
        "nativeName": "Kernewek"
    },
    "co": {
        "name": "Corsican",
        "nativeName": "corsu, lingua corsa"
    },
    "cr": {
        "name": "Cree",
        "nativeName": "ᓀᐦᐃᔭᐍᐏᐣ"
    },
    "hr": {
        "name": "Croatian",
        "nativeName": "hrvatski"
    },
    "cs": {
        "name": "Czech",
        "nativeName": "česky, čeština"
    },
    "da": {
        "name": "Danish",
        "nativeName": "dansk"
    },
    "dv": {
        "name": "Divehi; Dhivehi; Maldivian;",
        "nativeName": "ދިވެހި"
    },
    "nl": {
        "name": "Dutch",
        "nativeName": "Nederlands, Vlaams"
    },
    "en": {
        "name": "English",
        "nativeName": "English"
    },
    "eo": {
        "name": "Esperanto",
        "nativeName": "Esperanto"
    },
    "et": {
        "name": "Estonian",
        "nativeName": "eesti, eesti keel"
    },
    "ee": {
        "name": "Ewe",
        "nativeName": "Eʋegbe"
    },
    "fo": {
        "name": "Faroese",
        "nativeName": "føroyskt"
    },
    "fj": {
        "name": "Fijian",
        "nativeName": "vosa Vakaviti"
    },
    "fi": {
        "name": "Finnish",
        "nativeName": "suomi, suomen kieli"
    },
    "fr": {
        "name": "French",
        "nativeName": "français, langue française"
    },
    "ff": {
        "name": "Fula; Fulah; Pulaar; Pular",
        "nativeName": "Fulfulde, Pulaar, Pular"
    },
    "gl": {
        "name": "Galician",
        "nativeName": "Galego"
    },
    "ka": {
        "name": "Georgian",
        "nativeName": "ქართული"
    },
    "de": {
        "name": "German",
        "nativeName": "Deutsch"
    },
    "el": {
        "name": "Greek, Modern",
        "nativeName": "Ελληνικά"
    },
    "gn": {
        "name": "Guaraní",
        "nativeName": "Avañeẽ"
    },
    "gu": {
        "name": "Gujarati",
        "nativeName": "ગુજરાતી"
    },
    "ht": {
        "name": "Haitian; Haitian Creole",
        "nativeName": "Kreyòl ayisyen"
    },
    "ha": {
        "name": "Hausa",
        "nativeName": "Hausa, هَوُسَ"
    },
    "he": {
        "name": "Hebrew (modern)",
        "nativeName": "עברית"
    },
    "hz": {
        "name": "Herero",
        "nativeName": "Otjiherero"
    },
    "hi": {
        "name": "Hindi",
        "nativeName": "हिन्दी, हिंदी"
    },
    "ho": {
        "name": "Hiri Motu",
        "nativeName": "Hiri Motu"
    },
    "hu": {
        "name": "Hungarian",
        "nativeName": "Magyar"
    },
    "ia": {
        "name": "Interlingua",
        "nativeName": "Interlingua"
    },
    "id": {
        "name": "Indonesian",
        "nativeName": "Bahasa Indonesia"
    },
    "ie": {
        "name": "Interlingue",
        "nativeName": "Originally called Occidental; then Interlingue after WWII"
    },
    "ga": {
        "name": "Irish",
        "nativeName": "Gaeilge"
    },
    "ig": {
        "name": "Igbo",
        "nativeName": "Asụsụ Igbo"
    },
    "ik": {
        "name": "Inupiaq",
        "nativeName": "Iñupiaq, Iñupiatun"
    },
    "io": {
        "name": "Ido",
        "nativeName": "Ido"
    },
    "is": {
        "name": "Icelandic",
        "nativeName": "Íslenska"
    },
    "it": {
        "name": "Italian",
        "nativeName": "Italiano"
    },
    "iu": {
        "name": "Inuktitut",
        "nativeName": "ᐃᓄᒃᑎᑐᑦ"
    },
    "ja": {
        "name": "Japanese",
        "nativeName": "日本語 (にほんご／にっぽんご)"
    },
    "jv": {
        "name": "Javanese",
        "nativeName": "basa Jawa"
    },
    "kl": {
        "name": "Kalaallisut, Greenlandic",
        "nativeName": "kalaallisut, kalaallit oqaasii"
    },
    "kn": {
        "name": "Kannada",
        "nativeName": "ಕನ್ನಡ"
    },
    "kr": {
        "name": "Kanuri",
        "nativeName": "Kanuri"
    },
    "ks": {
        "name": "Kashmiri",
        "nativeName": "कश्मीरी, كشميري‎"
    },
    "kk": {
        "name": "Kazakh",
        "nativeName": "Қазақ тілі"
    },
    "km": {
        "name": "Khmer",
        "nativeName": "ភាសាខ្មែរ"
    },
    "ki": {
        "name": "Kikuyu, Gikuyu",
        "nativeName": "Gĩkũyũ"
    },
    "rw": {
        "name": "Kinyarwanda",
        "nativeName": "Ikinyarwanda"
    },
    "ky": {
        "name": "Kirghiz, Kyrgyz",
        "nativeName": "кыргыз тили"
    },
    "kv": {
        "name": "Komi",
        "nativeName": "коми кыв"
    },
    "kg": {
        "name": "Kongo",
        "nativeName": "KiKongo"
    },
    "ko": {
        "name": "Korean",
        "nativeName": "한국어 (韓國語), 조선말 (朝鮮語)"
    },
    "ku": {
        "name": "Kurdish",
        "nativeName": "Kurdî, كوردی‎"
    },
    "kj": {
        "name": "Kwanyama, Kuanyama",
        "nativeName": "Kuanyama"
    },
    "la": {
        "name": "Latin",
        "nativeName": "latine, lingua latina"
    },
    "lb": {
        "name": "Luxembourgish, Letzeburgesch",
        "nativeName": "Lëtzebuergesch"
    },
    "lg": {
        "name": "Luganda",
        "nativeName": "Luganda"
    },
    "li": {
        "name": "Limburgish, Limburgan, Limburger",
        "nativeName": "Limburgs"
    },
    "ln": {
        "name": "Lingala",
        "nativeName": "Lingála"
    },
    "lo": {
        "name": "Lao",
        "nativeName": "ພາສາລາວ"
    },
    "lt": {
        "name": "Lithuanian",
        "nativeName": "lietuvių kalba"
    },
    "lu": {
        "name": "Luba-Katanga",
        "nativeName": ""
    },
    "lv": {
        "name": "Latvian",
        "nativeName": "latviešu valoda"
    },
    "gv": {
        "name": "Manx",
        "nativeName": "Gaelg, Gailck"
    },
    "mk": {
        "name": "Macedonian",
        "nativeName": "македонски јазик"
    },
    "mg": {
        "name": "Malagasy",
        "nativeName": "Malagasy fiteny"
    },
    "ms": {
        "name": "Malay",
        "nativeName": "bahasa Melayu, بهاس ملايو‎"
    },
    "ml": {
        "name": "Malayalam",
        "nativeName": "മലയാളം"
    },
    "mt": {
        "name": "Maltese",
        "nativeName": "Malti"
    },
    "mi": {
        "name": "Māori",
        "nativeName": "te reo Māori"
    },
    "mr": {
        "name": "Marathi (Marāṭhī)",
        "nativeName": "मराठी"
    },
    "mh": {
        "name": "Marshallese",
        "nativeName": "Kajin M̧ajeļ"
    },
    "mn": {
        "name": "Mongolian",
        "nativeName": "монгол"
    },
    "na": {
        "name": "Nauru",
        "nativeName": "Ekakairũ Naoero"
    },
    "nv": {
        "name": "Navajo, Navaho",
        "nativeName": "Diné bizaad, Dinékʼehǰí"
    },
    "nb": {
        "name": "Norwegian Bokmål",
        "nativeName": "Norsk bokmål"
    },
    "nd": {
        "name": "North Ndebele",
        "nativeName": "isiNdebele"
    },
    "ne": {
        "name": "Nepali",
        "nativeName": "नेपाली"
    },
    "ng": {
        "name": "Ndonga",
        "nativeName": "Owambo"
    },
    "nn": {
        "name": "Norwegian Nynorsk",
        "nativeName": "Norsk nynorsk"
    },
    "no": {
        "name": "Norwegian",
        "nativeName": "Norsk"
    },
    "ii": {
        "name": "Nuosu",
        "nativeName": "ꆈꌠ꒿ Nuosuhxop"
    },
    "nr": {
        "name": "South Ndebele",
        "nativeName": "isiNdebele"
    },
    "oc": {
        "name": "Occitan",
        "nativeName": "Occitan"
    },
    "oj": {
        "name": "Ojibwe, Ojibwa",
        "nativeName": "ᐊᓂᔑᓈᐯᒧᐎᓐ"
    },
    "cu": {
        "name": "Old Church Slavonic, Church Slavic, Church Slavonic, Old Bulgarian, Old Slavonic",
        "nativeName": "ѩзыкъ словѣньскъ"
    },
    "om": {
        "name": "Oromo",
        "nativeName": "Afaan Oromoo"
    },
    "or": {
        "name": "Oriya",
        "nativeName": "ଓଡ଼ିଆ"
    },
    "os": {
        "name": "Ossetian, Ossetic",
        "nativeName": "ирон æвзаг"
    },
    "pa": {
        "name": "Panjabi, Punjabi",
        "nativeName": "ਪੰਜਾਬੀ, پنجابی‎"
    },
    "pi": {
        "name": "Pāli",
        "nativeName": "पाऴि"
    },
    "fa": {
        "name": "Persian",
        "nativeName": "فارسی"
    },
    "pl": {
        "name": "Polish",
        "nativeName": "polski"
    },
    "ps": {
        "name": "Pashto, Pushto",
        "nativeName": "پښتو"
    },
    "pt": {
        "name": "Portuguese",
        "nativeName": "Português"
    },
    "qu": {
        "name": "Quechua",
        "nativeName": "Runa Simi, Kichwa"
    },
    "rm": {
        "name": "Romansh",
        "nativeName": "rumantsch grischun"
    },
    "rn": {
        "name": "Kirundi",
        "nativeName": "kiRundi"
    },
    "ro": {
        "name": "Romanian, Moldavian, Moldovan",
        "nativeName": "română"
    },
    "ru": {
        "name": "Russian",
        "nativeName": "русский язык"
    },
    "sa": {
        "name": "Sanskrit (Saṁskṛta)",
        "nativeName": "संस्कृतम्"
    },
    "sc": {
        "name": "Sardinian",
        "nativeName": "sardu"
    },
    "sd": {
        "name": "Sindhi",
        "nativeName": "सिन्धी, سنڌي، سندھی‎"
    },
    "se": {
        "name": "Northern Sami",
        "nativeName": "Davvisámegiella"
    },
    "sm": {
        "name": "Samoan",
        "nativeName": "gagana faa Samoa"
    },
    "sg": {
        "name": "Sango",
        "nativeName": "yângâ tî sängö"
    },
    "sr": {
        "name": "Serbian",
        "nativeName": "српски језик"
    },
    "gd": {
        "name": "Scottish Gaelic; Gaelic",
        "nativeName": "Gàidhlig"
    },
    "sn": {
        "name": "Shona",
        "nativeName": "chiShona"
    },
    "si": {
        "name": "Sinhala, Sinhalese",
        "nativeName": "සිංහල"
    },
    "sk": {
        "name": "Slovak",
        "nativeName": "slovenčina"
    },
    "sl": {
        "name": "Slovene",
        "nativeName": "slovenščina"
    },
    "so": {
        "name": "Somali",
        "nativeName": "Soomaaliga, af Soomaali"
    },
    "st": {
        "name": "Southern Sotho",
        "nativeName": "Sesotho"
    },
    "es": {
        "name": "Spanish; Castilian",
        "nativeName": "español, castellano"
    },
    "su": {
        "name": "Sundanese",
        "nativeName": "Basa Sunda"
    },
    "sw": {
        "name": "Swahili",
        "nativeName": "Kiswahili"
    },
    "ss": {
        "name": "Swati",
        "nativeName": "SiSwati"
    },
    "sv": {
        "name": "Swedish",
        "nativeName": "svenska"
    },
    "ta": {
        "name": "Tamil",
        "nativeName": "தமிழ்"
    },
    "te": {
        "name": "Telugu",
        "nativeName": "తెలుగు"
    },
    "tg": {
        "name": "Tajik",
        "nativeName": "тоҷикӣ, toğikī, تاجیکی‎"
    },
    "th": {
        "name": "Thai",
        "nativeName": "ไทย"
    },
    "ti": {
        "name": "Tigrinya",
        "nativeName": "ትግርኛ"
    },
    "bo": {
        "name": "Tibetan Standard, Tibetan, Central",
        "nativeName": "བོད་ཡིག"
    },
    "tk": {
        "name": "Turkmen",
        "nativeName": "Türkmen, Түркмен"
    },
    "tl": {
        "name": "Tagalog",
        "nativeName": "Wikang Tagalog, ᜏᜒᜃᜅ᜔ ᜆᜄᜎᜓᜄ᜔"
    },
    "tn": {
        "name": "Tswana",
        "nativeName": "Setswana"
    },
    "to": {
        "name": "Tonga (Tonga Islands)",
        "nativeName": "faka Tonga"
    },
    "tr": {
        "name": "Turkish",
        "nativeName": "Türkçe"
    },
    "ts": {
        "name": "Tsonga",
        "nativeName": "Xitsonga"
    },
    "tt": {
        "name": "Tatar",
        "nativeName": "татарча, tatarça, تاتارچا‎"
    },
    "tw": {
        "name": "Twi",
        "nativeName": "Twi"
    },
    "ty": {
        "name": "Tahitian",
        "nativeName": "Reo Tahiti"
    },
    "ug": {
        "name": "Uighur, Uyghur",
        "nativeName": "Uyƣurqə, ئۇيغۇرچە‎"
    },
    "uk": {
        "name": "Ukrainian",
        "nativeName": "українська"
    },
    "ur": {
        "name": "Urdu",
        "nativeName": "اردو"
    },
    "uz": {
        "name": "Uzbek",
        "nativeName": "zbek, Ўзбек, أۇزبېك‎"
    },
    "ve": {
        "name": "Venda",
        "nativeName": "Tshivenḓa"
    },
    "vi": {
        "name": "Vietnamese",
        "nativeName": "Tiếng Việt"
    },
    "vo": {
        "name": "Volapük",
        "nativeName": "Volapük"
    },
    "wa": {
        "name": "Walloon",
        "nativeName": "Walon"
    },
    "cy": {
        "name": "Welsh",
        "nativeName": "Cymraeg"
    },
    "wo": {
        "name": "Wolof",
        "nativeName": "Wollof"
    },
    "fy": {
        "name": "Western Frisian",
        "nativeName": "Frysk"
    },
    "xh": {
        "name": "Xhosa",
        "nativeName": "isiXhosa"
    },
    "yi": {
        "name": "Yiddish",
        "nativeName": "ייִדיש"
    },
    "yo": {
        "name": "Yoruba",
        "nativeName": "Yorùbá"
    },
    "za": {
        "name": "Zhuang, Chuang",
        "nativeName": "Saɯ cueŋƅ, Saw cuengh"
    }
}


def getLanguage(code: str) -> str:
    if "-" in code:
        code = code.split("-")[0]
    return isoLangs.get(code).get('name')



import argparse
import sys
from argparse import ArgumentParser
from _version import __version__


def arguments():
    parser = ArgumentParser(prog="searchpie",
                            description="A handy tool to search through Wikipedia, Tmdb and Mal from command line",
                            usage="%(prog)s [-h] [-v,--version]", formatter_class=argparse.RawDescriptionHelpFormatter)

    arg_help = parser.add_argument_group(title="Search Flags", description="""
    -a, --anime <query>   searches mal for anime name 
    -b --manga <query>   searches mal for manga name 
    -m --movies <query>   searches tmdb for movie name
    -t --tv <query>   searches tmdb for tv show name
    -w --wiki <query>   searches wiki for wikipedia article


    searching TMDB for movies or TV shows requires tmdb api key, get your api key here:
    https://developers.themoviedb.org/3/getting-started/introduction

    In order to set api key use `searchpie --set-tmdb-key <your api key>`
    """)

    identifiers = parser.add_mutually_exclusive_group()

    parser.add_argument("default_method", metavar="default_query", type=str, nargs='*',
                             help="Searches in Default Method if no Search Flag provided")
    identifiers.add_argument("-a", "--anime", dest="anime", help=argparse.SUPPRESS, action='store', metavar='',
                             type=str,
                             nargs='+')
    identifiers.add_argument("-b", "--manga", dest="manga", help=argparse.SUPPRESS, action='store', metavar='',
                             type=str,
                             nargs='+')
    identifiers.add_argument("-m", "--movie", dest="movie", help=argparse.SUPPRESS, action='store', metavar='',
                             type=str,
                             nargs='+')
    identifiers.add_argument("-t", "--tv", dest="tv", help=argparse.SUPPRESS, action='store', metavar='', type=str,
                             nargs='+')
    identifiers.add_argument("-w", "--wiki", dest="wiki", help=argparse.SUPPRESS, action='store', metavar='', type=str,
                             nargs='+')
    identifiers.add_argument("-v", '--version', action='version',
                             version='%(prog)s {version}'.format(version=__version__))

    options = parser.add_mutually_exclusive_group()

    options.add_argument("-o", "--open", dest="browser", action='store_true', help="Opens page in browser")
    options.add_argument("-p", dest="pages", action='store', metavar="pages", default=1,
                         help="Number of results to be displayed, displays upto 10 results")
    options.add_argument("--set-default", dest="default", action='store_true', help="changes default method")
    options.add_argument("--show-default", dest="show_def", action='store_true', help="shows default method")
    options.add_argument("--set-tmdb-key", dest="key", action='store', help="changes api key for tmdb")

    if not len(sys.argv) > 1:
        parser.print_help()
        return None

    return parser.parse_args()
